@@ -1,6 +1,6 @@
 package Date::Holidays::GB;
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 # ABSTRACT: Determine British holidays - Current UK public and bank holiday dates up to 2016
 
@@ -174,7 +174,7 @@ sub _holiday {
     return join( ', ', @strings );
 }
 
-sub date_generated { '2016-01-29' }
+sub date_generated { '2017-08-09' }
 
 1;
 
@@ -344,3 +344,30 @@ __DATA__
 2017-12-26	EAW	Boxing Day
 2017-12-26	NIR	Boxing Day
 2017-12-26	SCT	Boxing Day
+2018-01-01	EAW	New Year’s Day
+2018-01-01	NIR	New Year’s Day
+2018-01-01	SCT	New Year’s Day
+2018-01-02	SCT	2nd January
+2018-03-19	NIR	St Patrick’s Day
+2018-03-30	EAW	Good Friday
+2018-03-30	NIR	Good Friday
+2018-03-30	SCT	Good Friday
+2018-04-02	EAW	Easter Monday
+2018-04-02	NIR	Easter Monday
+2018-05-07	EAW	Early May bank holiday
+2018-05-07	NIR	Early May bank holiday
+2018-05-07	SCT	Early May bank holiday
+2018-05-28	EAW	Spring bank holiday
+2018-05-28	NIR	Spring bank holiday
+2018-05-28	SCT	Spring bank holiday
+2018-07-12	NIR	Battle of the Boyne (Orangemen’s Day)
+2018-08-06	SCT	Summer bank holiday
+2018-08-27	EAW	Summer bank holiday
+2018-08-27	NIR	Summer bank holiday
+2018-11-30	SCT	St Andrew’s Day
+2018-12-25	EAW	Christmas Day
+2018-12-25	NIR	Christmas Day
+2018-12-25	SCT	Christmas Day
+2018-12-26	EAW	Boxing Day
+2018-12-26	NIR	Boxing Day
+2018-12-26	SCT	Boxing Day
